@@ -1,8 +1,10 @@
+from __future__ import unicode_literals
 
 # Authentication and Authorisation
 from functools import wraps
 from . import http
 
+
 def permit(test_func):
     '''Decorate a handler to control access'''
     def decorator(view_func):
@@ -14,10 +16,17 @@ def permit(test_func):
         return _wrapped_view
     return decorator
 
-permit_logged_in = permit(lambda self, request, *args, **kwargs: request.user.is_authenticated())
-permit_staff = permit(lambda self, request, *args, **kwargs: request.user.is_staff)
+permit_logged_in = permit(
+    lambda self, request, *args, **kwargs: request.user.is_authenticated()
+)
+
+permit_staff = permit(
+    lambda self, request, *args, **kwargs: request.user.is_staff
+)
+
 
 def permit_groups(*groups):
     def in_groups(request, *args):
-        return requets.user.groups.filter(name__in=args).exists()
-    return permit(lambda self, request, *args, **kwargs: in_groups(request, *groups))
+        return request.user.groups.filter(name__in=args).exists()
+    return permit(
+        lambda self, request, *args, **kwargs: in_groups(request, *groups))
