@@ -25,6 +25,17 @@ class BasePublisher(object):
         self.args = args
         self.kwargs = kwargs
 
+    @classmethod
+    def build_view(cls):
+        '''Builds the view function for this publisher.'''
+        @ensure_csrf_cookie
+        def view(request, *args, **kwargs):
+            '''A wrapper view to instantiate and dispatch'''
+            self = cls(request, *args, **kwargs)
+            return self.dispatch(request, **kwargs)
+
+        return view
+
     @classmethod
     def patterns(cls, api_name=None):
         '''
@@ -36,11 +47,7 @@ class BasePublisher(object):
         /object/(id)/           instance view
         /object/(id)/(action)/  custom action on instance
         '''
-        @ensure_csrf_cookie
-        def view(request, *args, **kwargs):
-            '''A wrapper view to instantiate and dispatch'''
-            self = cls(request, *args, **kwargs)
-            return self.dispatch(request, **kwargs)
+        view = cls.build_view()
 
         if api_name:
             name = '%s_%s' % (api_name, cls.api_name)
@@ -126,6 +133,48 @@ class BasePublisher(object):
         }
 
 
+class SimplePatternsMixin(object):
+    '''
+    A "flatter" set of url patterns for when your object IDs are numbers only.
+    '''
+
+    @classmethod
+    def patterns(cls, api_name=None):
+        view = cls.build_view()
+
+        if api_name:
+            name = '%s_%s' % (api_name, cls.api_name)
+        else:
+            name = cls.api_name
+
+        return [
+            url(r'^(?P<object_id>\d+)/(?P<action>\w+)/(?P<argument>.+?)/?$',
+                view,
+                name='%s_object_action_arg' % name
+            ),
+            url(r'^(?P<object_id>\d+)/(?P<action>\w+)/?$',
+                view,
+                name='%s_object_action' % name
+            ),
+            url(r'^(?P<object_id>\d+)/?$',
+                view,
+                name='%s_object_default' % name
+            ),
+            url(r'^(?P<action>\w+)/(?P<argument>.+?)/?$',
+                view,
+                name='%s_list_action_arg' % name
+            ),
+            url(r'^(?P<action>\w+)/?$',
+                view,
+                name='%s_list_action' % name
+            ),
+            url(r'^$',
+                view,
+                name='%s_list_default' % name
+            ),
+        ]
+
+
 class Publisher(BasePublisher):
     '''Default API-style publisher'''
     LIMIT_PARAM = 'limit'
@@ -166,6 +215,16 @@ class Publisher(BasePublisher):
         '''Return the object for the given id'''
         raise NotImplementedError
 
+    # List filtering and sorting
+
+    def filter_object_list(self, object_list):
+        '''Hook to allow custom filtering of object lists'''
+        return object_lsit
+
+    def sort_object_list(self, object_list):
+        '''Hook to allow custom sorting of object lists'''
+        return object_list
+
     # Pagination
 
     def get_page(self, object_list):
@@ -249,6 +308,9 @@ class Publisher(BasePublisher):
 
     def list_get_default(self, request, **kwargs):
         object_list = self.get_object_list()
+        object_list = self.filter_object_list(object_list)
+        object_list = self.sort_object_list(object_list)
+
         data = self.get_page(object_list)
 
         serialiser = self.get_serialiser()
